@@ -10,7 +10,7 @@
 use strict;
 use warnings;
 
-return [
+[
   {
     'author' => [
       'Dominique Dumont'
@@ -216,4 +216,3 @@ return [
   }
 ]
 ;
-
